<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:output encoding="ISO-8859-1" method="xml"/>
 	<xsl:decimal-format decimal-separator="," grouping-separator="." name="deutsch"/>


	<!-- *******************************************************************
		 Attribute sets
		 ******************************************************************* -->
	<xsl:attribute-set name = "DINA4">
    	<xsl:attribute name = "page-height">297mm</xsl:attribute>
	    <xsl:attribute name = "page-width">210mm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name = "erste-seite-raender">
    	<xsl:attribute name = "margin-top">11.2mm</xsl:attribute>
	    <xsl:attribute name = "margin-bottom">21mm</xsl:attribute>
    	<xsl:attribute name = "margin-left">25mm</xsl:attribute>
	    <xsl:attribute name = "margin-right">20mm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name = "seiten-raender">
    	<xsl:attribute name = "margin-top">11.2mm</xsl:attribute>
	    <xsl:attribute name = "margin-bottom">21mm</xsl:attribute>
    	<xsl:attribute name = "margin-left">25mm</xsl:attribute>
	    <xsl:attribute name = "margin-right">20mm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name = "rahmen-innen">
    	<xsl:attribute name = "border-color">black</xsl:attribute>
	    <xsl:attribute name = "border-style">solid</xsl:attribute>
	    <xsl:attribute name = "border-width">0.3pt</xsl:attribute>
	    <xsl:attribute name = "margin-left">1.0mm</xsl:attribute>
	    <xsl:attribute name = "margin-right">0.5mm</xsl:attribute>
	</xsl:attribute-set>


	<!-- *******************************************************************
		 Format erste Seite
		 ******************************************************************* -->
	<xsl:template name="ErsteSeite">
		<fo:simple-page-master master-name="ErsteSeite"
    			xsl:use-attribute-sets="DINA4 erste-seite-raender">
			<fo:region-body region-name="xsl-region-body" margin-top="20mm"
      			margin-bottom="10mm"/>

			<fo:region-before extent="50.5mm" region-name="erste-region-before"/>

			<fo:region-after extent="10mm" region-name="erste-region-after"/>

		</fo:simple-page-master>
	</xsl:template>

	<!-- *******************************************************************
		 Format gerade Seiten
		 ******************************************************************* -->
	<xsl:template name="GeradeSeiten">
		<fo:simple-page-master master-name="GeradeSeiten"
    			xsl:use-attribute-sets="DINA4 seiten-raender">
			<fo:region-body region-name="xsl-region-body" margin-top="20mm"
      			margin-bottom="10mm"/>

			<fo:region-before extent="50.5mm" region-name="gerade-region-before"/>

			<fo:region-after extent="10mm" region-name="gerade-region-after"/>

		</fo:simple-page-master>
	</xsl:template>

	<!-- *******************************************************************
		 Format ungerade Seiten
		 ******************************************************************* -->
	<xsl:template name="UngeradeSeiten">
		<fo:simple-page-master master-name="UngeradeSeiten"
    			xsl:use-attribute-sets="DINA4 seiten-raender">
			<fo:region-body region-name="xsl-region-body" margin-top="20mm"
      			margin-bottom="10mm"/>

			<fo:region-before extent="50.5mm" region-name="ungerade-region-before"/>

			<fo:region-after extent="10mm" region-name="ungerade-region-after"/>

		</fo:simple-page-master>
	</xsl:template>

	<!-- *******************************************************************
		 Sequence master
		 ******************************************************************* -->
	<xsl:template name="PageSequenceMaster">

		<fo:page-sequence-master master-name="PageSequenceMaster">
			<fo:repeatable-page-master-alternatives>
				<fo:conditional-page-master-reference master-reference="ErsteSeite"
						page-position="first"/>
				<fo:conditional-page-master-reference master-reference="GeradeSeiten"
						page-position="rest" odd-or-even="even"/>
		   		<fo:conditional-page-master-reference master-reference="UngeradeSeiten"
		   				page-position="rest" odd-or-even="odd"/>
			</fo:repeatable-page-master-alternatives>
		</fo:page-sequence-master>
	</xsl:template>


	<!-- *******************************************************************
		 Origa Logo
		 rechts oben
		 ******************************************************************* -->
	<xsl:template name="ParkerOrigaLogo">
		<fo:block-container height="100mm" width="50mm" top="0.0mm" left="130.0mm"
    		position="absolute" >
	    	<fo:block>
        		<fo:external-graphic content-width="40mm"
        				src="url(./config/images/logo_origa.png)"/>
	      	</fo:block>
    	</fo:block-container>
	</xsl:template>

	<!-- *******************************************************************
		 Linie Logo
		 unten; ber Origa Logo
		 ******************************************************************* -->
	<xsl:template name="LinieLogo">
		<fo:block-container height="10mm" width="180mm" top="265.5mm" left="0.0mm"
    		position="absolute" >
	    	<fo:block font-size="70%">www.parker-origa.com</fo:block>
	    	<fo:block font-size="10%">
        		<fo:external-graphic content-width="170mm"
        				src="url(./config/images/logo_linie.png)"/>
	      	</fo:block>
    	</fo:block-container>
	</xsl:template>


	<!-- *******************************************************************
		 Namenloses Template, das die eigentliche Funktionalitt bereitstellt.
		 ******************************************************************* -->
  	<xsl:template match="/">
    	<fo:root>

			<fo:layout-master-set>
	    		<xsl:call-template name="ErsteSeite"/>
	    		<xsl:call-template name="GeradeSeiten"/>
	    		<xsl:call-template name="UngeradeSeiten"/>

				<xsl:call-template name="PageSequenceMaster"/>
	      	</fo:layout-master-set>

	      	<fo:page-sequence master-reference="PageSequenceMaster">

		        <fo:static-content flow-name="erste-region-before">
			        <xsl:call-template name="ParkerOrigaLogo"/>
			        <xsl:call-template name="LinieLogo"/>
	        	</fo:static-content>

				<fo:static-content flow-name="gerade-region-before">
			        <xsl:call-template name="ParkerOrigaLogo"/>
			        <xsl:call-template name="LinieLogo"/>
	        	</fo:static-content>

	        	<fo:static-content flow-name="ungerade-region-before">
			        <xsl:call-template name="ParkerOrigaLogo"/>
			        <xsl:call-template name="LinieLogo"/>
	        	</fo:static-content>


        		<fo:flow flow-name="xsl-region-body">
					<fo:block white-space-collapse="false" font-size="9pt">
						<xsl:apply-templates/>
					</fo:block>

					<!-- Seitenumbruch - letzte Seite -->
					<!--
					<fo:block font-size="11pt"
							break-before="page">

			    		<xsl:call-template name="TabelleHeorbigerFirmen"/>
					</fo:block>
					-->
        		</fo:flow>
      		</fo:page-sequence>
    	</fo:root>
 	</xsl:template>

  <xsl:template match="sub">
	<fo:inline baseline-shift="sub" font-size="70%">
		<xsl:apply-templates/>
	</fo:inline>
  </xsl:template>

  <xsl:template match="sup">
	<fo:inline baseline-shift="super" font-size="70%">
		<xsl:apply-templates/>
	</fo:inline>
  </xsl:template>

  <xsl:template match="title">
	<fo:block font-weight="bold" font-size="120%">
		<xsl:apply-templates/>
	</fo:block>
  </xsl:template>

  <xsl:template match="section/name">
	<fo:block space-before="3mm" font-weight="bold">
		<xsl:apply-templates/>
	</fo:block>
  </xsl:template>

  <xsl:template match="valueGroup">
	<fo:block space-before="1mm">
	<fo:table table-layout="fixed" width="165mm">
		<fo:table-column column-number="1" column-width="60mm"/>
		<fo:table-column column-number="2"/>
		<fo:table-body>
			<fo:table-row>
				<fo:table-cell>
					<fo:block><xsl:apply-templates select="name"/></fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block><xsl:apply-templates select="value"/></fo:block>
				</fo:table-cell>
			</fo:table-row>
		</fo:table-body>
	</fo:table>
	</fo:block>
  </xsl:template>

  <xsl:template match="value">
	<fo:inline>
		<xsl:apply-templates/><xsl:text>    </xsl:text>
	</fo:inline>
  </xsl:template>


	<xsl:template match="table">
		<fo:block space-before="11pt">
			<fo:table table-layout="auto" width="168mm" border-collapse="collapse">
				<fo:table-column column-width="14mm"/>
				<fo:table-body>
					<xsl:apply-templates select="row"/>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template match="row">

		<xsl:choose>
			<xsl:when test="position()=1">
				<fo:table-row font-size="7pt" text-align="center" background-color="lightgrey">
					<xsl:apply-templates select="cell"/>
				</fo:table-row>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-row font-size="9pt" text-align="right">
					<xsl:apply-templates select="cell"/>
				</fo:table-row>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="cell">
		<fo:table-cell xsl:use-attribute-sets="rahmen-innen" display-align="center">
			<fo:block>
				<xsl:apply-templates/>
			</fo:block>
		</fo:table-cell>
	</xsl:template>


</xsl:stylesheet>
